==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/da.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galleri",
    "There was a problem reading files from this album" : "Der opstod et problem med at læse filer fra dette album",
    "Aborting preview. Could not find the file" : "Forlader forhåndsvisning. Kunne ikke finde filen",
    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - der findes allerede en fil med dette navn",
    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
    "Gallery view" : "Galleri visning",
    "Could not load the description" : "Kunne ikke indlæse beskrivelsen",
    "Could not load the description: " : "Kunne ikke indlæse beskrivelsen:",
    "Copyright" : "Ophavsret",
    "Could not load the copyright notice: " : "Kunne ikke indlæse notits om ophavsret:",
    "Copyright notice" : "Notits om ophavsret",
    "Link to copyright document" : "Henvisning til dokument om ophavsret",
    "This application may not work properly on your browser." : "Denne applikation fungerer muligvis ikke korrekt i din browser.",
    "For an improved experience, please install one of the following alternatives" : "For en bedre oplevelse, kan én af følgende alternativer installeres",
    "Your browser is not supported!" : "Din browser understøttes ikke!",
    "please install one of the following alternatives" : "installér venligst én af følgende alternativer",
    "Album cannot be shown" : "Album kan ikke vises",
    "No media files found" : "Ingen mediefiler fundet",
    "Upload pictures in the files app to display them here" : "Upload billeder i fil-app'en for at få dem vist her",
    "Upload new files via drag and drop or by using the [+] button above" : "Upload nye filer ved træk-og-slip eller ved at bruge [+]-knappen ovenfor",
    "Configuration error" : "Konfigurationsfejl",
    "New" : "Ny",
    "Hide Album" : "Skjul album",
    "Could not hide album" : "Kunne ikke skjule album",
    "Error loading slideshow template" : "Fejl ved indlæsning af skabelon for diasshow",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Fejl!</strong> Kunne ikke danne forhåndsvisning af denne fil.<br>Gå venligst til næste slide mens vi fjerner dette billede fra slideshow'et",
    "Next" : "Næste",
    "Play" : "Afspil",
    "Pause" : "Pause",
    "Previous" : "Forrige",
    "Close" : "Luk",
    "Download" : "Hent",
    "Toggle background" : "Slå baggrund til/fra",
    "Delete" : "Slet",
    "Could not create file \"{file}\" because it already exists" : "Kunne ikke oprette filen \"{file}\", fordi den allerede findes",
    "Could not create file \"{file}\"" : "Kunne ikke oprette filen \"{file}\"",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "Upload" : "Upload",
    "Error" : "Fejl",
    "Error while sharing" : "Fejl under deling",
    "Error while unsharing" : "Fejl under annullering af deling",
    "Error while changing permissions" : "Fejl under justering af rettigheder",
    "Shared with you and the group {group} by {owner}" : "Delt med dig og gruppen {group} af {owner}",
    "Shared with you by {owner}" : "Delt med dig af {owner}",
    "Share with users or groups …" : "Del med brugere eller grupper",
    "Share with users, groups or remote users …" : "Del med brugere, grupper eller eksterne brugere...",
    "Share" : "Del",
    "Share link" : "Del link",
    "The public link will expire no later than {days} days after it is created" : "Det offentlige link udløber senest {days} dage efter det blev oprettet",
    "Link" : "Link",
    "Password protect" : "Beskyt med adgangskode",
    "Password" : "Adgangskode",
    "Choose a password for the public link" : "Vælg et kodeord til det offentlige link",
    "Allow editing" : "Tillad redigering",
    "Email link to person" : "E-mail link til person",
    "Send" : "Send",
    "Set expiration date" : "Vælg udløbsdato",
    "Expiration" : "Udløb",
    "Expiration date" : "Udløbsdato",
    "An error occured. Please try again" : "Der skete en fejl. Prøv venligst igen",
    "Adding user..." : "Tilføjer bruger...",
    "group" : "gruppe",
    "remote" : "ekstern",
    "Resharing is not allowed" : "Videredeling ikke tilladt",
    "Error while retrieving shares" : "Fejl ved hentning af delinger",
    "Unshare" : "Fjern deling",
    "notify by email" : "Giv besked med mail",
    "can share" : "kan dele",
    "can edit" : "kan redigere",
    "access control" : "Adgangskontrol",
    "create" : "opret",
    "change" : "tilpas",
    "delete" : "slet",
    "Password protected" : "Beskyttet med adgangskode",
    "Error unsetting expiration date" : "Fejl ved fjernelse af udløbsdato",
    "Error setting expiration date" : "Fejl under sætning af udløbsdato",
    "Sending ..." : "Sender ...",
    "Email sent" : "E-mail afsendt",
    "Warning" : "Advarsel",
    "This share is password-protected" : "Delingen er beskyttet af kodeord",
    "The password is wrong. Try again." : "Kodeordet er forkert. Prøv igen.",
    "Sort by date" : "Sortér efter dato",
    "Sort by name" : "Sortér efter navn",
    "Cancel upload" : "Fortryd upload",
    "Album information" : "Information om album",
    "File list" : "Filoversigt",
    "Sorry, this file could not be found." : "Beklager, filen blev ikke fundet.",
    "Reasons might be:" : "Årsagen kan være:",
    "the wrong file ID was provided" : "der blev angivet et forkert fil-ID",
    "the file was removed" : "filen blev fjernet",
    "the file is corrupt" : "filen er beskadiget",
    "the encryption key is missing" : "krypteringsnøglen mangler",
    "Here is the error message returned by the server: " : "Her er fejlbeskeden som serveren sendte:",
    "Sorry, but the server could not fulfill your request." : "Beklager, men serveren kunne ikke opfylde din anmodning.",
    "Possible reasons for the problem:" : "Mulige årsager til problemet:",
    "a conflicting app was installed" : "en app med konflikter blev installeret",
    "a required component is missing or was disconnected" : "en påḱrævet komponent mangler eller blev slået fra",
    "the filesystem is not readable" : "filsystemet kan ikke aflæses",
    "For more information, please contact your friendly ownCloud administrator." : "For mere information, så kontakt din venlige ownCloud-administrator.",
    "Sorry, this link doesn't seem to work anymore." : "Beklager, linket ser ikke længere ud til at virke.",
    "the item was removed" : "Filen blev fjernet",
    "the link has expired" : "linket er udløbet",
    "sharing is disabled" : "deling er deaktiveret",
    "For more information, please ask the person who has sent you this link." : "For mere information, så spørg personen som sendte dig dette link.",
    "Picture view" : "Billedvisning"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/da.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galleri",
    "There was a problem reading files from this album" : "Der opstod et problem med at læse filer fra dette album",
    "Aborting preview. Could not find the file" : "Forlader forhåndsvisning. Kunne ikke finde filen",
    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - der findes allerede en fil med dette navn",
    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
    "No compatible server found at {remote}" : "Ingen kompatible servere fundet på {remote}",
    "Invalid server url" : "Ugyldig server url",
    "Could not load the description" : "Kunne ikke indlæse beskrivelsen",
    "Could not load the description: " : "Kunne ikke indlæse beskrivelsen:",
    "Copyright" : "Ophavsret",
    "Could not load the copyright notice: " : "Kunne ikke indlæse notits om ophavsret:",
    "Copyright notice" : "Notits om ophavsret",
    "Link to copyright document" : "Henvisning til dokument om ophavsret",
    "This application may not work properly on your browser." : "Denne applikation fungerer muligvis ikke korrekt i din browser.",
    "For an improved experience, please install one of the following alternatives" : "For en bedre oplevelse, kan én af følgende alternativer installeres",
    "Your browser is not supported!" : "Din browser understøttes ikke!",
    "please install one of the following alternatives" : "installér venligst én af følgende alternativer",
    "Album cannot be shown" : "Album kan ikke vises",
    "No media files found" : "Ingen mediefiler fundet",
    "Upload new files via drag and drop or by using the [+] button above" : "Upload nye filer ved træk-og-slip eller ved at bruge [+]-knappen ovenfor",
    "Configuration error" : "Konfigurationsfejl",
    "New" : "Ny",
    "Hide Album" : "Skjul album",
    "Could not hide album" : "Kunne ikke skjule album",
    "Error loading slideshow template" : "Fejl ved indlæsning af skabelon for diasshow",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Fejl!</strong> Kunne ikke danne forhåndsvisning af denne fil.<br>Gå venligst til næste slide mens vi fjerner dette billede fra slideshow'et",
    "Next" : "Næste",
    "Play" : "Afspil",
    "Pause" : "Pause",
    "Previous" : "Forrige",
    "Close" : "Luk",
    "Download" : "Hent",
    "Toggle background" : "Slå baggrund til/fra",
    "Delete" : "Slet",
    "Could not create file \"{file}\" because it already exists" : "Kunne ikke oprette filen \"{file}\", fordi den allerede findes",
    "Could not create file \"{file}\"" : "Kunne ikke oprette filen \"{file}\"",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tilladt filtype",
    "Upload" : "Upload",
    "Error" : "Fejl",
    "Error while sharing" : "Fejl under deling",
    "Error while unsharing" : "Fejl under annullering af deling",
    "Error while changing permissions" : "Fejl under justering af rettigheder",
    "Shared with you and the group {group} by {owner}" : "Delt med dig og gruppen {group} af {owner}",
    "Shared with you by {owner}" : "Delt med dig af {owner}",
    "Share with users or groups …" : "Del med brugere eller grupper",
    "Share with users, groups or remote users …" : "Del med brugere, grupper eller eksterne brugere...",
    "Share" : "Del",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Del med andre på en anden server ved hjælp af deres Federated Cloud id username@example.com/cloud ",
    "Share link" : "Del link",
    "The public link will expire no later than {days} days after it is created" : "Det offentlige link udløber senest {days} dage efter det blev oprettet",
    "Link" : "Link",
    "Password protect" : "Beskyt med adgangskode",
    "Password" : "Adgangskode",
    "Choose a password for the public link" : "Vælg et kodeord til det offentlige link",
    "Allow editing" : "Tillad redigering",
    "Email link to person" : "E-mail link til person",
    "Send" : "Send",
    "Set expiration date" : "Vælg udløbsdato",
    "Expiration" : "Udløb",
    "Expiration date" : "Udløbsdato",
    "This list is maybe truncated - please refine your search term to see more results." : "Listen er måske afkortet - optimer dine søgeord for at se flere resultater.",
    "No users or groups found for {search}" : "Ingen brugere eller grupper fundet for {search}",
    "No users found for {search}" : "Ingen brugere fundet for {search}",
    "An error occured. Please try again" : "Der skete en fejl. Prøv venligst igen",
    "Adding user..." : "Tilføjer bruger...",
    "group" : "gruppe",
    "remote" : "ekstern",
    "Resharing is not allowed" : "Videredeling ikke tilladt",
    "Error while retrieving shares" : "Fejl ved hentning af delinger",
    "Unshare" : "Fjern deling",
    "notify by email" : "Giv besked med mail",
    "can share" : "kan dele",
    "can edit" : "kan redigere",
    "access control" : "Adgangskontrol",
    "create" : "opret",
    "change" : "tilpas",
    "delete" : "slet",
    "Password protected" : "Beskyttet med adgangskode",
    "Error unsetting expiration date" : "Fejl ved fjernelse af udløbsdato",
    "Error setting expiration date" : "Fejl under sætning af udløbsdato",
    "Sending ..." : "Sender ...",
    "Email sent" : "E-mail afsendt",
    "Warning" : "Advarsel",
    "This share is password-protected" : "Delingen er beskyttet af kodeord",
    "The password is wrong. Try again." : "Kodeordet er forkert. Prøv igen.",
    "Sort by date" : "Sortér efter dato",
    "Sort by name" : "Sortér efter navn",
    "Cancel upload" : "Fortryd upload",
    "Album information" : "Information om album",
    "File list" : "Filoversigt",
    "Sorry, this file could not be found." : "Beklager, filen blev ikke fundet.",
    "Reasons might be:" : "Årsagen kan være:",
    "the wrong file ID was provided" : "der blev angivet et forkert fil-ID",
    "the file was removed" : "filen blev fjernet",
    "the file is corrupt" : "filen er beskadiget",
    "the encryption key is missing" : "krypteringsnøglen mangler",
    "Here is the error message returned by the server: " : "Her er fejlbeskeden som serveren sendte:",
    "For more information, please contact your friendly Nextcloud administrator." : "For mere information, kontakt din venlige Nextcloud administrator.",
    "Sorry, but the server could not fulfill your request." : "Beklager, men serveren kunne ikke opfylde din anmodning.",
    "Possible reasons for the problem:" : "Mulige årsager til problemet:",
    "a conflicting app was installed" : "en app med konflikter blev installeret",
    "a required component is missing or was disconnected" : "en påḱrævet komponent mangler eller blev slået fra",
    "the filesystem is not readable" : "filsystemet kan ikke aflæses",
    "Sorry, this link doesn't seem to work anymore." : "Beklager, linket ser ikke længere ud til at virke.",
    "the item was removed" : "Filen blev fjernet",
    "the link has expired" : "linket er udløbet",
    "sharing is disabled" : "deling er deaktiveret",
    "For more information, please ask the person who has sent you this link." : "For mere information, så spørg personen som sendte dig dette link.",
    "Add to your Nextcloud" : "Tilføj til din Nextcloud",
    "Picture view" : "Billedvisning",
    "Gallery view" : "Galleri visning"
},
"nplurals=2; plural=(n != 1);");
